@@ -9,13 +9,13 @@ import peewee as pw
 # Package information
 # ===================
 
-__version__ = "1.4.5"
+__version__ = "1.4.6"
 __project__ = "peewee_migrate"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "BSD"
 
 
-LOGGER = logging.getLogger(__name__)
+LOGGER: logging.Logger = logging.getLogger(__name__)
 LOGGER.addHandler(logging.StreamHandler())
 LOGGER.setLevel(logging.INFO)
 
@@ -30,4 +30,8 @@ class MigrateHistory(pw.Model):
         """String representation."""
         return self.name
 
+
+MIGRATE_TABLE = 'migratehistory'
+
+
 from .router import Migrator, Router # noqa
